==> tabula_1.6.1.tar.gz: tabula/inst/doc/diversity.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----packages-----------------------------------------------------------------
# Load packages
library(tabula)
library(folio) # Datasets
library(magrittr)

## ----richness-----------------------------------------------------------------
mississippi %>%
  as_count() %>%
  index_richness(method = "margalef")

## ----asymptotic-richness------------------------------------------------------
mississippi %>%
  as_count() %>%
  index_composition(method = "chao1")

## ----rarefaction--------------------------------------------------------------
mississippi %>%
  as_count() %>%
  rarefaction(sample = 10, method = "hurlbert", simplify = TRUE) %>%
  head()

## ----diversity----------------------------------------------------------------
mississippi %>%
  as_count() %>%
  index_heterogeneity(method = "shannon")

## ----evenness-----------------------------------------------------------------
mississippi %>%
  as_count() %>%
  index_evenness(method = "shannon")

## ----refine-------------------------------------------------------------------
mississippi %>%
  as_count() %>%
  jackknife_evenness(method = "shannon")

## ----similarity, fig.width=7, fig.height=5, fig.align="center"----------------
# Brainerd-Robinson (similarity between assemblages)
mississippi %>%
  as_count() %>%
  similarity(method = "brainerd") %>%
  plot_spot() +
  khroma::scale_colour_YlOrBr()

# Binomial co-occurrence (similarity between types)
mississippi %>%
  as_count() %>%
  similarity(method = "binomial") %>%
  plot_spot() +
  khroma::scale_colour_PRGn()

## ----sample-size, fig.width=3.5, fig.height=3.5, fig.show='hold'--------------
## Data from Conkey 1980, Kintigh 1989, p. 28
chevelon <- as_count(chevelon)

sim_evenness <- simulate_heterogeneity(chevelon, method = "shannon")
plot(sim_evenness) +
  ggplot2::theme_bw() +
  ggplot2::theme(legend.position = "bottom")

sim_richness <- simulate_richness(chevelon, method = "none")
plot(sim_richness) +
  ggplot2::theme_bw() +
  ggplot2::theme(legend.position = "bottom")

## ----plot-rank, fig.width=7, fig.height=5, fig.align="center"-----------------
mississippi %>%
  as_count() %>%
  plot_rank(log = "xy") +
  ggplot2::theme_bw() +
  khroma::scale_color_discreterainbow()

==> tabula_1.7.0.tar.gz: tabula/inst/doc/diversity.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----packages-----------------------------------------------------------------
# Load packages
library(tabula)
library(folio) # Datasets

## ----richness-----------------------------------------------------------------
richness(mississippi, method = "margalef")

## ----asymptotic-richness------------------------------------------------------
composition(mississippi, method = "chao1")

## ----diversity----------------------------------------------------------------
heterogeneity(mississippi, method = "shannon")

## ----evenness-----------------------------------------------------------------
evenness(mississippi, method = "shannon")

## ----similarity, fig.width=7, fig.height=5, fig.align="center"----------------
# Brainerd-Robinson (similarity between assemblages)
BR <- similarity(mississippi, method = "brainerd")
plot_spot(BR) +
  khroma::scale_colour_YlOrBr()

# Binomial co-occurrence (similarity between types)
BI <- similarity(mississippi, method = "binomial")
plot_spot(BI) +
  khroma::scale_colour_PRGn()

## ----rarefaction--------------------------------------------------------------
RA <- rarefaction(mississippi, sample = 100, method = "hurlbert")

plot(RA)

## ----sample-size, fig.width=3.5, fig.height=3.5, fig.show='hold'--------------
## Data from Conkey 1980, Kintigh 1989, p. 28
HE <- heterogeneity(chevelon, method = "shannon")
HE_sim <- simulate(HE)
plot(HE_sim)

RI <- index_richness(chevelon, method = "count")
RI_sim <- simulate(RI)
plot(RI_sim) 

## ----plot-rank, fig.width=7, fig.height=5, fig.align="center"-----------------
plot_rank(mississippi, log = "xy") +
  ggplot2::theme_bw() +
  khroma::scale_color_discreterainbow()
